package com.qmth.distributed.print.business.bean.result.report;

import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.qmth.distributed.print.business.bean.dto.report.CourseTargetDto;
import io.swagger.annotations.ApiModelProperty;
import org.hibernate.validator.constraints.Range;

import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import java.io.Serializable;
import java.util.List;

/**
 * @Description: 试卷蓝图result
 * @Param:
 * @return:
 * @Author: wangliang
 * @Date: 2024/2/19
 */
public class PaperStructResult implements Serializable {

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "id")
    private Long id;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "考试id")
    @NotNull(message = "考试id不能为空")
    private Long examId;

    @ApiModelProperty(value = "课程编码")
    @NotNull(message = "课程编码不能为空")
    private String courseCode;

    @ApiModelProperty(value = "课程名称")
    @NotNull(message = "课程名称不能为空")
    private String courseName;

    @ApiModelProperty(value = "试卷编号")
    @NotNull(message = "试卷编号不能为空")
    private String paperNumber;

    @ApiModelProperty(value = "大题号")
    @NotNull(message = "大题号不能为空")
    @Range(min = 1L, message = "大题号最小为1")
    private Integer mainNumber;

    @ApiModelProperty(value = "小题号")
    @NotNull(message = "小题号不能为空")
    @Range(min = 1L, message = "小题号最小为1")
    private Integer subNumber;

    @ApiModelProperty(value = "分数")
    private Double score;

    @ApiModelProperty(value = "课程目标集合")
    @NotEmpty(message = "课程目标集合不能为空")
    private List<CourseTargetDto> targetList;

    public String getCourseName() {
        return courseName;
    }

    public void setCourseName(String courseName) {
        this.courseName = courseName;
    }

    public Integer getMainNumber() {
        return mainNumber;
    }

    public void setMainNumber(Integer mainNumber) {
        this.mainNumber = mainNumber;
    }

    public Integer getSubNumber() {
        return subNumber;
    }

    public void setSubNumber(Integer subNumber) {
        this.subNumber = subNumber;
    }

    public Double getScore() {
        return score;
    }

    public void setScore(Double score) {
        this.score = score;
    }

    public List<CourseTargetDto> getTargetList() {
        return targetList;
    }

    public void setTargetList(List<CourseTargetDto> targetList) {
        this.targetList = targetList;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getExamId() {
        return examId;
    }

    public void setExamId(Long examId) {
        this.examId = examId;
    }

    public String getCourseCode() {
        return courseCode;
    }

    public void setCourseCode(String courseCode) {
        this.courseCode = courseCode;
    }

    public String getPaperNumber() {
        return paperNumber;
    }

    public void setPaperNumber(String paperNumber) {
        this.paperNumber = paperNumber;
    }
}
